==> xdatabase-1.0.5.tar.gz: example/xdatabase_example.dart <==
import 'package:uuid/uuid.dart';
import 'package:xdatabase/xdatabase.dart';

@Table('log_table')
@Index(name: '_idx_log_ts', columns: ['local_id', 'create_ts'])
class Log {
  @Field(type: 'VARCHAR(36)', primary: true)
  late String localId = '';
  @Field(type: 'VARCHAR(66)', mark: '作者ID')
  late String autherId = '';
  @Field(type: 'VARCHAR(66)', mark: '作者ID')
  late String userId = '';
  @Field(type: 'TEXT', mark: '内容')
  late String body = '';
  @Field(type: 'INT', mark: '创建事件')
  late int createTs = 0;
  @Field(type: 'INT', mark: '修改事件')
  late int updateTs = 0;
  Log();
  Log.make(
      {required this.localId,
      required this.autherId,
      required this.body,
      required this.createTs});

  @override
  String toString() {
    return 'id:$localId auth:$autherId, body:$body ts:$createTs';
  }
}

Future work() async {
  DeclarationHolder().registTable(Log);
  Database().init(ConnectionSetting(
      host: '127.0.0.1',
      port: 5432,
      dbName: 'xbase',
      userName: 'alex',
      password: ''));

  final conn = await Database().getConnection();
  final insertCount = await Orm<Log>(conn).insert(Log.make(
      localId: Uuid().v4().toString(),
      autherId: 'alex',
      body: 'afdfsadasf',
      createTs: DateTime.now().millisecondsSinceEpoch ~/ 1000));
  print('insert $insertCount Log');
  final results =
      await Orm<Log>(conn).query('SELECT * FROM [table]').fetch(null);
  results.forEach((log) {
    print('log:$log');
  });
  return conn.release();
}

Future miguration() async {
  DeclarationHolder().registTable(Log);
  Migration(tables: [Log]).releaseVersion();
}

void main(List<String> args) {
  miguration().then((_) => {});
  print('done!');
}

==> xdatabase-1.0.7.tar.gz: example/xdatabase_example.dart <==
import 'package:uuid/uuid.dart';
import 'package:xdatabase/xdatabase.dart';

@Table('log_table')
@Index(name: '_idx_log_ts', columns: ['local_id', 'create_ts'])
class Log {
  @Field(type: 'VARCHAR(36)', primary: true)
  late String localId = '';
  @Field(type: 'VARCHAR(66)', mark: '作者ID')
  late String autherId = '';
  @Field(type: 'VARCHAR(66)', mark: '作者ID')
  late String userId = '';
  @Field(type: 'TEXT', mark: '内容')
  late String body = '';
  @Field(type: 'INT', mark: '创建事件')
  late int createTs = 0;
  @Field(type: 'INT', mark: '修改事件')
  late int updateTs = 0;
  Log();
  Log.make(
      {required this.localId,
      required this.autherId,
      required this.body,
      required this.createTs});

  @override
  String toString() {
    return 'id:$localId auth:$autherId, body:$body ts:$createTs';
  }
}

@Table('user_table')
@UniqueIndex(name: '_idx_user_name', columns: ['name'])
class User {
  @Field(type: 'VARCHAR(66)', mark: '作者ID')
  late String name;
  @Field(type: 'VARCHAR(66)', mark: '密码')
  late String password;
  User();
  User.make({required this.name, required this.password});
}

Future work() async {
  DeclarationHolder().registTable(Log);
  DeclarationHolder().registTable(User);
  Database().init(ConnectionSetting(
      host: '127.0.0.1',
      port: 5432,
      dbName: 'xbase',
      userName: 'alex',
      password: ''));

  final conn = await Database().getConnection();
  final insertCount = await Orm<Log>(conn).insert(Log.make(
      localId: Uuid().v4().toString(),
      autherId: 'alex',
      body: 'afdfsadasf',
      createTs: DateTime.now().millisecondsSinceEpoch ~/ 1000));
  print('insert $insertCount Log');
  final results =
      await Orm<Log>(conn).query('SELECT * FROM [table]').fetch(null);
  results.forEach((log) {
    print('log:$log');
  });
  return conn.release();
}

Future miguration() async {
  DeclarationHolder().registTable(Log);
  DeclarationHolder().registTable(User);
  Migration(tables: [Log, User]).diffVersion();
}

void main(List<String> args) {
  miguration().then((_) => {});
  print('done!');
}
